==> openGion6.8.1.0_dev.zip: uap/webapps/ge/db/DERBY/sql/install/08_CMNT/CMNT_TBL.sql <==
COMMENT ON TABLE GE12       IS 'ｼｽﾃﾑﾊﾟﾗﾒｰﾀ定義'        ;
COMMENT ON TABLE GE15       IS 'ｱｸｾｽ調査ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE16       IS 'ﾕｰｻﾞｰﾊﾟﾗﾒｰﾀ定義'       ;
COMMENT ON TABLE GE17       IS 'URL転送ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GE20       IS 'ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GE30       IS 'ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ'           ;
COMMENT ON TABLE GE31       IS '定型文ﾏｽﾀ'             ;
COMMENT ON TABLE GE32       IS '送信履歴ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE33       IS 'ｸﾞﾙｰﾌﾟﾏｽﾀ'             ;
COMMENT ON TABLE GE34       IS '宛先ﾃｰﾌﾞﾙ'             ;
COMMENT ON TABLE GE36       IS 'ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GE37       IS 'ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ'         ;
COMMENT ON TABLE GE38       IS 'ﾌｧｲﾙ種別ﾏｽﾀ'           ;
COMMENT ON TABLE GE39       IS 'ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE50       IS '帳票要求ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE51       IS '帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE52       IS '帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE53       IS '振分条件ﾏｽﾀ'           ;
COMMENT ON TABLE GE54       IS '帳票定義ﾏｽﾀ'           ;
COMMENT ON TABLE GE55       IS '出力先ﾏｽﾀ'             ;
COMMENT ON TABLE GE56       IS '帳票ｴﾗｰﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GE57       IS '雛形明細定義ﾃｰﾌﾞﾙ'     ;
COMMENT ON TABLE GE58       IS 'RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE62       IS '伝送定義ﾏｽﾀ'           ;
COMMENT ON TABLE GE70       IS '取込要求ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE71       IS '取込実績ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE72       IS 'ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE74       IS '処理定義ﾏｽﾀ'           ;
COMMENT ON TABLE GE76       IS '取込ｴﾗｰﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GE80       IS 'FAQﾃｰﾌﾞﾙ'              ;
COMMENT ON TABLE GE81       IS '新着情報ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GEA03      IS 'ｶﾗﾑ定義'               ;
COMMENT ON TABLE GEA04      IS 'ｺｰﾄﾞ定義'              ;
COMMENT ON TABLE GEA05      IS 'ﾛｰﾙﾏｽﾀ'                ;
COMMENT ON TABLE GEA06      IS 'ﾃﾞｰﾀﾛｰﾙﾏｽﾀ'            ;
COMMENT ON TABLE GEA08      IS '項目名称定義(ﾗﾍﾞﾙ)'    ;
COMMENT ON TABLE GEA09      IS 'ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GEA10      IS 'ﾕｰｻﾞｰ定義'             ;
COMMENT ON TABLE GEA11      IS '画面定義'              ;
COMMENT ON TABLE WKGE52_XIN IS 'WKGE52_XIN'            ;
COMMENT ON TABLE WKGE54_XIN IS 'WKGE54_XIN'            ;

==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/DERBY/sql/install/08_CMNT/CMNT_TBL.sql <==
COMMENT ON TABLE GE12       IS 'ｼｽﾃﾑﾊﾟﾗﾒｰﾀ定義'        ;
COMMENT ON TABLE GE15       IS 'ｱｸｾｽ調査ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE16       IS 'ﾕｰｻﾞｰﾊﾟﾗﾒｰﾀ定義'       ;
COMMENT ON TABLE GE17       IS 'URL転送ﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GE18       IS '位置情報管理ﾃｰﾌﾞﾙ'     ;
COMMENT ON TABLE GE20       IS 'ﾕｰｻﾞｰﾛｰﾙ設定値ﾃｰﾌﾞﾙ'   ;
COMMENT ON TABLE GE30       IS 'ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ'           ;
COMMENT ON TABLE GE31       IS '定型文ﾏｽﾀ'             ;
COMMENT ON TABLE GE32       IS '送信履歴ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE33       IS 'ｸﾞﾙｰﾌﾟﾏｽﾀ'             ;
COMMENT ON TABLE GE34       IS '宛先ﾃｰﾌﾞﾙ'             ;
COMMENT ON TABLE GE36       IS 'ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ'      ;
COMMENT ON TABLE GE37       IS 'ﾒｰﾙﾎｽﾄ振分ﾏｽﾀ'         ;
COMMENT ON TABLE GE38       IS 'ﾌｧｲﾙ種別ﾏｽﾀ'           ;
COMMENT ON TABLE GE39       IS 'ﾌｧｲﾙ管理ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE50       IS '帳票要求ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE51       IS '帳票ﾃﾞｰﾀﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE52       IS '帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE53       IS '振分条件ﾏｽﾀ'           ;
COMMENT ON TABLE GE54       IS '帳票定義ﾏｽﾀ'           ;
COMMENT ON TABLE GE55       IS '出力先ﾏｽﾀ'             ;
COMMENT ON TABLE GE56       IS '帳票ｴﾗｰﾃｰﾌﾞﾙ'          ;
COMMENT ON TABLE GE57       IS '雛形明細定義ﾃｰﾌﾞﾙ'     ;
COMMENT ON TABLE GE58       IS 'RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE70       IS '取込要求ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE71       IS '取込実績ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE72       IS 'ﾌｧｲﾙﾚｲｱｳﾄﾃｰﾌﾞﾙ'        ;
COMMENT ON TABLE GE80       IS 'FAQﾃｰﾌﾞﾙ'              ;
COMMENT ON TABLE GE81       IS '新着情報ﾃｰﾌﾞﾙ'         ;
COMMENT ON TABLE GE82       IS 'DB定義書管理テーブル'  ;
COMMENT ON TABLE GEA03      IS 'ｶﾗﾑ定義'               ;
COMMENT ON TABLE GEA04      IS 'ｺｰﾄﾞ定義'              ;
COMMENT ON TABLE GEA05      IS 'ﾛｰﾙﾏｽﾀ'                ;
COMMENT ON TABLE GEA06      IS 'ﾃﾞｰﾀﾛｰﾙﾏｽﾀ'            ;
COMMENT ON TABLE GEA08      IS '項目名称定義(ﾗﾍﾞﾙ)'    ;
COMMENT ON TABLE GEA09      IS 'ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ';
COMMENT ON TABLE GEA10      IS 'ﾕｰｻﾞｰ定義'             ;
COMMENT ON TABLE GEA11      IS '画面定義'              ;
COMMENT ON TABLE WKGE52_XIN IS 'WKGE52_XIN'            ;
COMMENT ON TABLE WKGE54_XIN IS 'WKGE54_XIN'            ;
